@@ -15,7 +15,7 @@
 This is the development documentation of zim.
 
 B{NOTE:} There is also some generic development documentation in the
-"HACKING" folder in the source distribution. Please also have a look
+"CONTRIBUTING.md" file in the source distribution. Please also have a look
 at that if you want to help with zim development.
 
 In this API documentation many of the methods with names starting with
@@ -93,7 +93,7 @@ Some generic base classes and functions can be found in L{zim.utils}
 
 
 # Bunch of meta data, used at least in the about dialog
-__version__ = '0.73.2'
+__version__ = '0.73.3'
 __url__ = 'https://www.zim-wiki.org'
 __author__ = 'Jaap Karssenberg <jaap.karssenberg@gmail.com>'
 __copyright__ = 'Copyright 2008 - 2019 Jaap Karssenberg <jaap.karssenberg@gmail.com>'
